@@ -1,5 +1,4 @@
 ### library(poolr); library(testthat); Sys.setenv(NOT_CRAN="true")
-library(poolr)
 
 source("tolerances.r")
 
@@ -8,7 +7,7 @@ context("Checking mvnconv() function")
 test_that("empirical() works correctly.", {
 
   set.seed(1234)
-  emp_test_alpha <- binotest(grid2ip.p, adjust = "empirical", R = grid2ip.ld, alpha = 0.1)
+  emp_test_alpha <- binomtest(grid2ip.p, adjust = "empirical", R = grid2ip.ld, alpha = 0.1)
 
   set.seed(1234)
   emp_test_batch <- fisher(grid2ip.p, adjust = "empirical", R = grid2ip.ld, size = 1000, batchsize = 300)
@@ -16,8 +15,8 @@ test_that("empirical() works correctly.", {
   set.seed(1234)
   emp_test_side1 <- fisher(grid2ip.p, adjust = "empirical", R = grid2ip.ld, size = 1000, side = 1)
 
-  expect_equivalent(emp_test_alpha$p, 0.0029997, tolerance = p_tol * emp_sca)
-  expect_equivalent(emp_test_batch$p, 0.002997003, tolerance = p_tol * emp_sca)
+  expect_equivalent(emp_test_alpha$p, 0.00149985, tolerance = p_tol * emp_sca)
+  expect_equivalent(emp_test_batch$p, 0.001998002, tolerance = p_tol * emp_sca)
   expect_equivalent(emp_test_side1$p, 0.000999001, tolerance = p_tol * emp_sca)
 
 })
